/**
 * @file
 * Entity Reference Tree JavaScript file.
 */

// Codes run both on normal page loads and when data is loaded by AJAX (or BigPipe!)
// @See https://www.drupal.org/docs/drupal-apis/javascript-api/javascript-api-overview
(function ($, Drupal, once) {
  Drupal.behaviors.buildCalendarBlock = {
    attach: function (context, settings) {
      var dialogWidth = [400];
      var dialogType = ['modal'];
      var dialogOpen = [1];
      
      // Redirect to the URL
      function gotoURL(url) {
        let eventURL = new URL(url, location.origin);
        if (eventURL.origin !== "null") {
          window.location = url;
        }
      }

      // Event click callback
      function eventClick(info) {
        info.jsEvent.preventDefault();
        let blockIndex = parseInt(this.el.getAttribute("calendar-block-index"));
        if (info.event.url && dialogOpen[blockIndex] === "1") {
          let ajaxSettings = {
            url: info.event.url,
            dialogType: dialogType[blockIndex],
            dialog: { width: dialogWidth[blockIndex] },
          };
          let openDialog = Drupal.ajax(ajaxSettings).execute();

          openDialog.done(function() {
            // The modal dialog open successfully.
          }).fail(function() {
            // The Ajax modal couldn't open.
            // Open in a new tab instead.
            gotoURL(info.event.url);
          });
        }
        else if (info.event.url) {
          gotoURL(info.event.url);
        }
      }
      
      // Function to build calendar objects.
      function buildCalendars() {
        $('.fullcalendar-block')
          .each(function() {
            let blockIndex = parseInt(this.getAttribute("calendar-block-index"));
            let blockSettings = drupalSettings.fullCalendarBlock[blockIndex];
            var calendarOptions = JSON.parse(blockSettings.calendar_options);
            
            dialogOpen[blockIndex] = blockSettings.dialog_open;
            dialogWidth[blockIndex] = blockSettings.dialog_width;
            dialogType[blockIndex] = 'modal';
            
            // Bind the event click handler.
            calendarOptions.eventClick = eventClick;


            var calendar = new FullCalendar.Calendar(this, calendarOptions);
            calendar.render();
          });
      }
      
      once('buildCalendarBlock', 'html', context).forEach( function () {
        // Build all calendars.
        buildCalendars();
      })
    }
  }
})(jQuery, Drupal, once);